@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2016 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2018 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -457,6 +457,9 @@ void sipe_backend_media_set_encryption_keys(struct sipe_media_call *media,
 					    struct sipe_media_stream *stream,
 					    const guchar *encryption_key,
 					    const guchar *decryption_key);
+void sipe_backend_media_set_require_encryption(struct sipe_media_call *media,
+					       struct sipe_media_stream *stream,
+					       const gboolean require_encryption);
 
 /* Stream handling */
 void sipe_backend_stream_hold(struct sipe_media_call *media,
@@ -685,7 +688,8 @@ void sipe_backend_user_feedback_typing_stop(struct sipe_core_public *sipe_public
  * @param sipe_public   The handle representing the protocol instance
  * @param message       Text of the query to be shown to user
  * @param accept_label  Label to be displayed on UI control that accepts query
- * @param decline_label Label to be displayed on UI control that declines query
+ * @param decline_label Label to be displayed on UI control that declines query.
+ *                      When @c NULL, the control will not be shown.
  * @param key           Opaque handle uniquely identifying the query. Backend
  *                      should store it for the case SIPE core requests the
  *                      query to be closed prematurely.
@@ -696,6 +700,21 @@ void sipe_backend_user_ask(struct sipe_core_public *sipe_public,
 			   const gchar *decline_label,
 			   gpointer key);
 
+/**
+ * Present a set of options to the user to choose from.
+ *
+ * @param sipe_public (in) The handle representing the protocol instance
+ * @param message     (in) Text message to be shown to the user
+ * @param choices     (in) List of choice options
+ * @param key         (in) Opaque handle uniquely identifying the query. Backend
+ *                    should store it for the case SIPE core requests the query
+ *                    to be closed prematurely.
+ */
+void sipe_backend_user_ask_choice(struct sipe_core_public *sipe_public,
+				  const gchar *message,
+				  GSList *choices,
+				  gpointer key);
+
 /**
  * Closes the pending user query
  *
@@ -961,9 +980,19 @@ void sipe_backend_buddy_set_blocked_status(struct sipe_core_public *sipe_public,
 					   const gchar *who,
 					   gboolean blocked);
 
+/**
+ * Set the buddy status
+ *
+ * @param sipe_public The handle representing the protocol instance making the call
+ * @param who The name of the user whose status should be updated
+ * @param activity New activity
+ * @param last_active Seconds since epoch when user entered idle state.
+ *        May be @c 0 if unknown.
+ */
 void sipe_backend_buddy_set_status(struct sipe_core_public *sipe_public,
 				   const gchar *who,
-				   guint activity);
+				   guint activity,
+	                           time_t last_active);
 
 /**
  * Checks whether backend has a capability to use buddy photos. If this function
@@ -1070,6 +1099,9 @@ enum sipe_buddy_menu_type {
 	SIPE_BUDDY_MENU_ACCESS_LEVEL_HELP,
 	SIPE_BUDDY_MENU_CHANGE_ACCESS_LEVEL,
 	SIPE_BUDDY_MENU_ADD_NEW_DOMAIN,
+	SIPE_BUDDY_MENU_SHARE_DESKTOP,
+	SIPE_BUDDY_MENU_GIVE_DESKTOP_CONTROL,
+	SIPE_BUDDY_MENU_TAKE_DESKTOP_CONTROL,
 	SIPE_BUDDY_MENU_TYPES
 };
 
