@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2017 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2018 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -226,7 +226,8 @@ void sipe_core_change_access_level_for_domain(struct sipe_core_public *sipe_publ
 #define SIPE_ACTIVITY_IN_MEETING  14
 #define SIPE_ACTIVITY_OOF         15
 #define SIPE_ACTIVITY_URGENT_ONLY 16
-#define SIPE_ACTIVITY_NUM_TYPES   17 /* use to define array size */
+#define SIPE_ACTIVITY_IN_PRES     17
+#define SIPE_ACTIVITY_NUM_TYPES   18 /* use to define array size */
 
 const gchar *sipe_core_activity_description(guint type);
 
@@ -246,9 +247,19 @@ gchar *sipe_core_buddy_status(struct sipe_core_public *sipe_public,
 			      guint activity,
 			      const gchar *status_text);
 
+/**
+ * Received new status for buddy.
+ *
+ * @param sipe_public Sipe core public data structure.
+ * @param uri         SIP URI of the buddy
+ * @param activity    Activity value for buddy
+ * @param last_active Seconds since epoch when buddy entered idle state
+ *                    May be @c 0 if unknown or buddy is not idle.
+ */
 void sipe_core_buddy_got_status(struct sipe_core_public *sipe_public,
 				const gchar *uri,
-				guint activity);
+				guint activity,
+	                        time_t last_active);
 
 /**
  * Trigger generation of buddy information label/text pairs
@@ -421,17 +432,23 @@ gchar *
 sipe_core_conf_entry_info(struct sipe_core_public *sipe_public,
 			  struct sipe_chat_session *chat_session);
 
+typedef enum {
+	SIPE_APPSHARE_ROLE_NONE,
+	SIPE_APPSHARE_ROLE_VIEWER,
+	SIPE_APPSHARE_ROLE_PRESENTER
+} sipe_appshare_role;
+
 /**
- * Checks if given chat session has an open RDP client window.
+ * Gets user's application sharing role in given chat session.
  *
  * @param sipe_public (in) SIPE core data.
  * @param chat_session (in) chat session structure
  *
- * @return @c TRUE if RDP session is in progress.
+ * @return User's application sharing role.
  */
-gboolean
-sipe_core_conf_is_viewing_appshare(struct sipe_core_public *sipe_public,
-				   struct sipe_chat_session *chat_session);
+sipe_appshare_role
+sipe_core_conf_get_appshare_role(struct sipe_core_public *sipe_public,
+				 struct sipe_chat_session *chat_session);
 
 /* call control (CSTA) */
 void sipe_core_buddy_make_call(struct sipe_core_public *sipe_public,
@@ -535,6 +552,45 @@ void sipe_core_appshare_connect_conference(struct sipe_core_public *sipe_public,
 					   struct sipe_chat_session *chat_session,
 					   gboolean user_must_accept);
 
+/**
+ * Starts presenting user's desktop
+ *
+ * @param sipe_public (in) SIPE core data.
+ * @param with (in) SIP URI of the contact to share the desktop with.
+ */
+void sipe_core_appshare_share_desktop(struct sipe_core_public *sipe_public,
+				      const gchar *with);
+
+/**
+ * Starts presenting user's desktop with a conference call
+ *
+ * @param sipe_public (in) SIPE core data.
+ * @param chat_session (in) chat session structure.
+ */
+void
+sipe_core_conf_share_desktop(struct sipe_core_public *sipe_public,
+			     struct sipe_chat_session *chat_session);
+
+/**
+ * Changes the state of remote desktop control on an application sharing call.
+ *
+ * @param call (in) media call structure.
+ * @param enabled (in) @c TRUE to enable remote control, @c FALSE to disable it.
+ */
+void
+sipe_core_appshare_set_remote_control(struct sipe_media_call *call,
+				      gboolean enabled);
+
+/**
+ * Gets the state of remote desktop control on an application sharing call.
+ *
+ * @param call (in) media call structure.
+ *
+ * @return @c TRUE if remote control is enabled, otherwise @c FALSE.
+ */
+gboolean
+sipe_core_appshare_get_remote_control(struct sipe_media_call *call);
+
 /* group chat */
 gboolean sipe_core_groupchat_query_rooms(struct sipe_core_public *sipe_public);
 void sipe_core_groupchat_join(struct sipe_core_public *sipe_public,
@@ -554,6 +610,10 @@ void sipe_core_user_feedback_typing(struct sipe_core_public *sipe_public,
 
 void sipe_core_user_ask_cb(gpointer key, gboolean accepted);
 
+static const guint SIPE_CHOICE_CANCELLED = G_MAXUINT;
+
+void sipe_core_user_ask_choice_cb(gpointer key, guint choice_id);
+
 /* groups */
 void sipe_core_group_rename(struct sipe_core_public *sipe_public,
 			    const gchar *old_name,
