@@ -97,6 +97,8 @@ remmina_launch(struct sipe_rdp_client *client, GSocketAddress *listen_address,
 
 	g_file_set_contents(client_data->config_file, config_file,
 			    strlen(config_file), &error);
+	SIPE_DEBUG_INFO("Written .remmina file %s:\n%s",
+			client_data->config_file, config_file);
 	g_free(config_file);
 	if (error) {
 		SIPE_DEBUG_ERROR("Couldn't write remmina config file: %s",
@@ -109,6 +111,8 @@ remmina_launch(struct sipe_rdp_client *client, GSocketAddress *listen_address,
 				  client->cmdline,
 				  client_data->config_file);
 
+	SIPE_DEBUG_INFO("Launching remmina: %s", cmdline);
+
 	g_spawn_command_line_async(cmdline, &error);
 	g_free(cmdline);
 	if (error) {
