@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2017 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,10 +45,12 @@
 #include "sipe-conf.h"
 #include "sipe-core.h"
 #include "sipe-core-private.h"
+#include "sipe-appshare.h"
 #include "sipe-digest.h"
 #include "sipe-group.h"
 #include "sipe-http.h"
 #include "sipe-im.h"
+#include "sipe-media.h"
 #include "sipe-nls.h"
 #include "sipe-ocs2005.h"
 #include "sipe-ocs2007.h"
@@ -754,7 +756,8 @@ void sipe_core_buddy_remove(struct sipe_core_public *sipe_public,
 
 void sipe_core_buddy_got_status(struct sipe_core_public *sipe_public,
 				const gchar *uri,
-				guint activity)
+				guint activity,
+	                        time_t last_active)
 {
 	struct sipe_core_private *sipe_private = SIPE_CORE_PRIVATE;
 	struct sipe_buddy *sbuddy = sipe_buddy_find_by_uri(sipe_private,
@@ -766,7 +769,10 @@ void sipe_core_buddy_got_status(struct sipe_core_public *sipe_public,
 	 * then set/preserve it.
 	 */
 	if (SIPE_CORE_PRIVATE_FLAG_IS(OCS2007)) {
-		sipe_backend_buddy_set_status(sipe_public, uri, activity);
+		sipe_backend_buddy_set_status(sipe_public,
+					      uri,
+					      activity,
+			                      last_active);
 	} else {
 		sipe_ocs2005_apply_calendar_status(sipe_private,
 						   sbuddy,
@@ -945,7 +951,7 @@ static gchar * prepare_buddy_search_query(GSList *query_rows, gboolean use_dlx)
 	gchar *query = NULL;
 
 	while (query_rows) {
-		gchar *attr;
+		const gchar *attr;
 		gchar *value;
 		gchar *tmp = NULL;
 
@@ -2370,6 +2376,34 @@ struct sipe_backend_buddy_menu *sipe_core_buddy_create_menu(struct sipe_core_pub
 		}
 	}
 
+#ifdef HAVE_APPSHARE_SERVER
+	{
+		struct sipe_media_call *call = sipe_media_call_find(SIPE_CORE_PRIVATE,
+								    buddy_name);
+
+		if (call && sipe_appshare_get_role(call) == SIPE_APPSHARE_ROLE_PRESENTER) {
+			/* We're already presenting to this buddy. */
+
+			if (sipe_core_appshare_get_remote_control(call)) {
+				menu = sipe_backend_buddy_menu_add(sipe_public, menu,
+						_("Take desktop control"),
+						SIPE_BUDDY_MENU_TAKE_DESKTOP_CONTROL,
+						call);
+			} else {
+				menu = sipe_backend_buddy_menu_add(sipe_public, menu,
+						_("Give desktop control"),
+						SIPE_BUDDY_MENU_GIVE_DESKTOP_CONTROL,
+						call);
+			}
+		} else {
+			menu = sipe_backend_buddy_menu_add(sipe_public, menu,
+							   _("Share my desktop"),
+							   SIPE_BUDDY_MENU_SHARE_DESKTOP,
+							   NULL);
+		}
+	}
+#endif // HAVE_APPSHARE_SERVER
+
 	/* access level control */
 	if (SIPE_CORE_PRIVATE_FLAG_IS(OCS2007))
 		menu = sipe_backend_buddy_sub_menu_add(sipe_public,
