@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2017 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -144,7 +144,11 @@ static const gchar * const sipe_core_build_options[] = {
 	"Lync FT",
 #endif
 #ifdef HAVE_APPSHARE
-	"Application Sharing",
+#ifdef HAVE_APPSHARE_SERVER
+	"Application Sharing - full",
+#else
+	"Application Sharing - client only",
+#endif
 #endif
 #endif
 
@@ -210,7 +214,7 @@ gchar *sipe_core_about(void)
 		/* 3,4 */ "%s: <a href=\"http://sourceforge.net/p/sipe/discussion/688534/\">%s</a><br/>"
 		/* 5,6 */   "%s: <a href=\"" PACKAGE_BUGREPORT "\">%s</a><br/>"
 		/* 7 */   "%s: <a href=\"" SIPE_TRANSLATIONS_URL "\">Transifex.com</a><br/>"
-		/* 8 */   "%s: GPLv2+<br/>"
+		/* 8 */   "%s: GPL-2.0-or-later<br/>"
 		"<br/>"
 		/* 9 (REMOVED) */
 		/* 10,11 */ "%s<a href=\"" SIPE_TRANSLATIONS_URL "\">Transifex.com</a>%s.<br/>"
@@ -391,7 +395,7 @@ void sipe_core_backend_initialized(struct sipe_core_private *sipe_private,
 void sipe_core_connection_cleanup(struct sipe_core_private *sipe_private)
 {
 	sipe_http_free(sipe_private);
-	sip_transport_disconnect(sipe_private);
+	sip_transport_drop(sipe_private);
 
 	sipe_schedule_cancel_all(sipe_private);
 
@@ -461,6 +465,7 @@ void sipe_core_deallocate(struct sipe_core_public *sipe_public)
 	g_free(sipe_private->public.sip_name);
 	g_free(sipe_private->public.sip_domain);
 	g_free(sipe_private->username);
+	g_free(sipe_private->user_agent);
 	g_free(sipe_private->email_password);
 	g_free(sipe_private->email_authuser);
 	g_free(sipe_private->email);
@@ -507,6 +512,68 @@ void sipe_core_email_authentication(struct sipe_core_private *sipe_private,
 	}
 }
 
+const gchar *sipe_core_user_agent(struct sipe_core_private *sipe_private)
+{
+	if (!sipe_private->user_agent) {
+		const gchar *useragent = sipe_backend_setting(SIPE_CORE_PUBLIC,
+							      SIPE_SETTING_USER_AGENT);
+		if (is_empty(useragent)) {
+/*@TODO: better approach to define _user_ OS, it's version and host architecture */
+/* ref: lzodefs.h */
+#if defined(__linux__) || defined(__linux) || defined(__LINUX__)
+  #define SIPE_TARGET_PLATFORM "linux"
+#elif defined(__NetBSD__) ||defined( __OpenBSD__) || defined(__FreeBSD__)
+  #define SIPE_TARGET_PLATFORM "bsd"
+#elif defined(__APPLE__) || defined(__MACOS__)
+  #define SIPE_TARGET_PLATFORM "macosx"
+#elif defined(_AIX) || defined(__AIX__) || defined(__aix__)
+  #define SIPE_TARGET_PLATFORM "aix"
+#elif defined(__solaris__) || defined(__sun)
+  #define SIPE_TARGET_PLATFORM "sun"
+#elif defined(_WIN32)
+  #define SIPE_TARGET_PLATFORM "win"
+#elif defined(__CYGWIN__)
+  #define SIPE_TARGET_PLATFORM "cygwin"
+#elif defined(__hpux__)
+  #define SIPE_TARGET_PLATFORM "hpux"
+#elif defined(__sgi__)
+  #define SIPE_TARGET_PLATFORM "irix"
+#else
+  #define SIPE_TARGET_PLATFORM "unknown"
+#endif
+
+#if defined(__amd64__) || defined(__x86_64__) || defined(_M_AMD64)
+  #define SIPE_TARGET_ARCH "x86_64"
+#elif defined(__386__) || defined(__i386__) || defined(__i386) || defined(_M_IX86) || defined(_M_I386)
+  #define SIPE_TARGET_ARCH "i386"
+#elif defined(__ppc64__)
+  #define SIPE_TARGET_ARCH "ppc64"
+#elif defined(__powerpc__) || defined(__powerpc) || defined(__ppc__) || defined(__PPC__) || defined(_M_PPC) || defined(_ARCH_PPC) || defined(_ARCH_PWR)
+  #define SIPE_TARGET_ARCH "ppc"
+#elif defined(__hppa__) || defined(__hppa)
+  #define SIPE_TARGET_ARCH "hppa"
+#elif defined(__mips__) || defined(__mips) || defined(_MIPS_ARCH) || defined(_M_MRX000)
+  #define SIPE_TARGET_ARCH "mips"
+#elif defined(__s390__) || defined(__s390) || defined(__s390x__) || defined(__s390x)
+  #define SIPE_TARGET_ARCH "s390"
+#elif defined(__sparc__) || defined(__sparc) || defined(__sparcv8)
+  #define SIPE_TARGET_ARCH "sparc"
+#elif defined(__arm__)
+  #define SIPE_TARGET_ARCH "arm"
+#else
+  #define SIPE_TARGET_ARCH "other"
+#endif
+			gchar *backend = sipe_backend_version();
+			sipe_private->user_agent = g_strdup_printf("%s Sipe/" PACKAGE_VERSION " (" SIPE_TARGET_PLATFORM "-" SIPE_TARGET_ARCH ")",
+								   backend);
+			g_free(backend);
+		} else {
+			sipe_private->user_agent = g_strdup(useragent);
+		}
+	}
+	return(sipe_private->user_agent);
+}
+
 /*
   Local Variables:
   mode: c
