@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2017 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,12 +32,12 @@
 #include "sipmsg.h"
 #include "sip-csta.h"
 #include "sip-transport.h"
-#include "sipe-appshare.h"
 #include "sipe-backend.h"
 #include "sipe-chat.h"
 #include "sipe-conf.h"
 #include "sipe-core.h"
 #include "sipe-core-private.h"
+#include "sipe-appshare.h"
 #include "sipe-dialog.h"
 #include "sipe-ft.h"
 #include "sipe-ft-lync.h"
@@ -56,8 +56,8 @@
 void process_incoming_bye(struct sipe_core_private *sipe_private,
 			  struct sipmsg *msg)
 {
-	const gchar *callid = sipmsg_find_header(msg, "Call-ID");
-	gchar *from = parse_from(sipmsg_find_header(msg, "From"));
+	const gchar *callid = sipmsg_find_call_id_header(msg);
+	gchar *from = sipmsg_parse_from_address(msg);
 	struct sip_session *session;
 	struct sip_dialog *dialog;
 
@@ -124,7 +124,7 @@ void process_incoming_bye(struct sipe_core_private *sipe_private,
 void process_incoming_cancel(struct sipe_core_private *sipe_private,
 			     struct sipmsg *msg)
 {
-	const gchar *callid = sipmsg_find_header(msg, "Call-ID");
+	const gchar *callid = sipmsg_find_call_id_header(msg);
 
 #ifdef HAVE_VV
 	struct sipe_media_call_private *call_private =
@@ -142,8 +142,8 @@ void process_incoming_cancel(struct sipe_core_private *sipe_private,
 void process_incoming_info(struct sipe_core_private *sipe_private,
 			   struct sipmsg *msg)
 {
-	const gchar *contenttype = sipmsg_find_header(msg, "Content-Type");
-	const gchar *callid = sipmsg_find_header(msg, "Call-ID");
+	const gchar *contenttype = sipmsg_find_content_type_header(msg);
+	const gchar *callid = sipmsg_find_call_id_header(msg);
 	gchar *from;
 	struct sip_session *session;
 
@@ -168,7 +168,7 @@ void process_incoming_info(struct sipe_core_private *sipe_private,
 	}
 #endif
 
-	from = parse_from(sipmsg_find_header(msg, "From"));
+	from = sipmsg_parse_from_address(msg);
 	session = sipe_session_find_chat_or_im(sipe_private, callid, from);
 	if (!session) {
 		g_free(from);
@@ -271,7 +271,7 @@ static void sipe_invite_mime_cb(gpointer user_data, const GSList *fields,
 	const gchar *type;
 	gchar *body_lcase;
 
-	if (g_str_has_prefix(sipmsg_find_header(msg, "Content-Type"),
+	if (g_str_has_prefix(sipmsg_find_content_type_header(msg),
 			     "application/sdp")) {
 		/* We have already found suitable alternative and set message's body
 		 * and Content-Type accordingly. */
@@ -373,18 +373,15 @@ void sipe_incoming_cancel_delayed_invite(struct sipe_core_private *sipe_private,
 void process_incoming_invite(struct sipe_core_private *sipe_private,
 			     struct sipmsg *msg)
 {
-	gchar *newTag;
-	const gchar *oldHeader;
-	gchar *newHeader;
 	gboolean is_multiparty = FALSE;
 	gboolean was_multiparty = TRUE;
 	gboolean just_joined = FALSE;
 	gchar *from;
-	const gchar *callid         = sipmsg_find_header(msg, "Call-ID");
+	const gchar *callid         = sipmsg_find_call_id_header(msg);
 	const gchar *roster_manager = sipmsg_find_header(msg, "Roster-Manager");
 	const gchar *end_points_hdr = sipmsg_find_header(msg, "EndPoints");
 	const gchar *trig_invite    = sipmsg_find_header(msg, "TriggeredInvite");
-	const gchar *content_type   = sipmsg_find_header(msg, "Content-Type");
+	const gchar *content_type   = sipmsg_find_content_type_header(msg);
 	const gchar *subject        = sipmsg_find_header(msg, "Subject");
 	GSList *end_points = NULL;
 	struct sip_session *session;
@@ -396,7 +393,7 @@ void process_incoming_invite(struct sipe_core_private *sipe_private,
 	if (g_str_has_prefix(content_type, "multipart/alternative")) {
 		sipe_mime_parts_foreach(content_type, msg->body, sipe_invite_mime_cb, msg);
 		/* Reload Content-Type to get type of the selected message part */
-		content_type = sipmsg_find_header(msg, "Content-Type");
+		content_type = sipmsg_find_content_type_header(msg);
 	}
 #endif
 
@@ -424,7 +421,7 @@ void process_incoming_invite(struct sipe_core_private *sipe_private,
 	/* Application sharing */
 	if (sipe_strcase_equal(content_type, "application/sdp") && msg->body &&
 	    strstr(msg->body, "m=applicationsharing") &&
-	    sipe_strequal(sipmsg_find_header(msg, "CSeq"), "1 INVITE")) {
+	    sipe_strequal(sipmsg_find_cseq_header(msg), "1 INVITE")) {
 #ifdef HAVE_APPSHARE
 		process_incoming_invite_appshare(sipe_private, msg);
 #else
@@ -449,14 +446,7 @@ void process_incoming_invite(struct sipe_core_private *sipe_private,
 	}
 
 	// TODO There *must* be a better way to clean up the To header to add a tag...
-	SIPE_DEBUG_INFO_NOFORMAT("Adding a Tag to the To Header on Invite Request...");
-	oldHeader = sipmsg_find_header(msg, "To");
-	newTag = gentag();
-	newHeader = g_strdup_printf("%s;tag=%s", oldHeader, newTag);
-	g_free(newTag);
-	sipmsg_remove_header_now(msg, "To");
-	sipmsg_add_header_now(msg, "To", newHeader);
-	g_free(newHeader);
+	sipmsg_update_to_header_tag(msg);
 
 	if (end_points_hdr) {
 		end_points = sipmsg_parse_endpoints_header(end_points_hdr);
@@ -512,7 +502,7 @@ void process_incoming_invite(struct sipe_core_private *sipe_private,
 	}
 
 	/* IM session */
-	from = parse_from(sipmsg_find_header(msg, "From"));
+	from = sipmsg_parse_from_address(msg);
 	if (!session)
 		session = sipe_session_find_or_add_im(sipe_private, from);
 
@@ -521,7 +511,7 @@ void process_incoming_invite(struct sipe_core_private *sipe_private,
 	session->callid = g_strdup(callid);
 
 	if (is_multiparty && end_points) {
-		gchar *to = parse_from(sipmsg_find_header(msg, "To"));
+		gchar *to = sipmsg_parse_to_address(msg);
 		GSList *entry = end_points;
 		while (entry) {
 			struct sipendpoint *end_point = entry->data;
@@ -614,7 +604,9 @@ void process_incoming_invite(struct sipe_core_private *sipe_private,
 			{
 				dont_delay = TRUE;
 			}
-			else if (g_str_has_prefix(ms_text_format, "text/plain") || g_str_has_prefix(ms_text_format, "text/html"))
+			else if (g_str_has_prefix(ms_text_format, "text/plain") ||
+				 g_str_has_prefix(ms_text_format, "text/html")  ||
+				 g_str_has_prefix(ms_text_format, "text/rtf"))
 			{
 				/* please do not optimize logic inside as this code may be re-enabled for other cases */
 				gchar *html = get_html_message(ms_text_format, NULL);
@@ -656,19 +648,20 @@ void process_incoming_message(struct sipe_core_private *sipe_private,
 	const gchar *contenttype;
 	gboolean found = FALSE;
 
-	from = parse_from(sipmsg_find_header(msg, "From"));
+	from = sipmsg_parse_from_address(msg);
 
 	if (!from) return;
 
 	SIPE_DEBUG_INFO("got message from %s: %s", from, msg->body);
 
-	contenttype = sipmsg_find_header(msg, "Content-Type");
-	if (g_str_has_prefix(contenttype, "text/plain")
-	    || g_str_has_prefix(contenttype, "text/html")
-	    || g_str_has_prefix(contenttype, "multipart/related")
-	    || g_str_has_prefix(contenttype, "multipart/alternative"))
+	contenttype = sipmsg_find_content_type_header(msg);
+	if (g_str_has_prefix(contenttype, "text/plain")            ||
+	    g_str_has_prefix(contenttype, "text/html")             ||
+	    g_str_has_prefix(contenttype, "text/rtf")              ||
+	    g_str_has_prefix(contenttype, "multipart/related")     ||
+	    g_str_has_prefix(contenttype, "multipart/alternative"))
 	{
-		const gchar *callid = sipmsg_find_header(msg, "Call-ID");
+		const gchar *callid = sipmsg_find_call_id_header(msg);
 		gchar *html = get_html_message(contenttype, msg->body);
 
 		struct sip_session *session = sipe_session_find_chat_or_im(sipe_private,
@@ -676,7 +669,7 @@ void process_incoming_message(struct sipe_core_private *sipe_private,
 									   from);
 		if (session && session->chat_session) {
 			if (session->chat_session->type == SIPE_CHAT_TYPE_CONFERENCE) { /* a conference */
-				gchar *tmp = parse_from(sipmsg_find_header(msg, "Ms-Sender"));
+				gchar *tmp = sipmsg_parse_address_from_header(msg, "Ms-Sender");
 				gchar *sender = parse_from(tmp);
 				g_free(tmp);
 				sipe_backend_chat_message(SIPE_CORE_PUBLIC,
@@ -736,7 +729,7 @@ void process_incoming_message(struct sipe_core_private *sipe_private,
 		sip_transport_response(sipe_private, msg, 200, "OK", NULL);
 		found = TRUE;
 	} else if (g_str_has_prefix(contenttype, "text/x-msmsgsinvite")) {
-		const gchar *callid = sipmsg_find_header(msg, "Call-ID");
+		const gchar *callid = sipmsg_find_call_id_header(msg);
 		struct sip_session *session = sipe_session_find_chat_or_im(sipe_private,
 									   callid,
 									   from);
@@ -755,7 +748,7 @@ void process_incoming_message(struct sipe_core_private *sipe_private,
 		}
 	}
 	if (!found) {
-		const gchar *callid = sipmsg_find_header(msg, "Call-ID");
+		const gchar *callid = sipmsg_find_call_id_header(msg);
 		struct sip_session *session = sipe_session_find_chat_or_im(sipe_private,
 									   callid,
 									   from);
@@ -799,9 +792,9 @@ void process_incoming_refer(struct sipe_core_private *sipe_private,
 			    struct sipmsg *msg)
 {
 	gchar *self = sip_uri_self(sipe_private);
-	const gchar *callid = sipmsg_find_header(msg, "Call-ID");
-	gchar *from = parse_from(sipmsg_find_header(msg, "From"));
-	gchar *refer_to = parse_from(sipmsg_find_header(msg, "Refer-to"));
+	const gchar *callid = sipmsg_find_call_id_header(msg);
+	gchar *from = sipmsg_parse_from_address(msg);
+	gchar *refer_to = sipmsg_parse_address_from_header(msg, "Refer-to");
 	gchar *referred_by = g_strdup(sipmsg_find_header(msg, "Referred-By"));
 	struct sip_session *session;
 	struct sip_dialog *dialog;
