@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2011-2017 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2011-2019 SIPE Project <http://sipe.sourceforge.net/>
  * Copyright (C) 2010 Jakub Adam <jakub.adam@ktknet.cz>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -45,6 +45,7 @@
 #include "sipe-session.h"
 #include "sipe-utils.h"
 #include "sipe-nls.h"
+#include "sipe-schedule.h"
 #include "sipe-xml.h"
 
 /* [MS-SDPEXT] 3.1.5.31.2 says a range size of 100 SHOULD be used for video and
@@ -72,6 +73,8 @@ struct sipe_media_call_private {
 
 	struct sdpmsg			*smsg;
 	GSList				*failed_media;
+	gchar 				*ringing_key;
+	gchar 				*timeout_key;
 };
 #define SIPE_MEDIA_CALL         ((struct sipe_media_call *) call_private)
 #define SIPE_MEDIA_CALL_PRIVATE ((struct sipe_media_call_private *) call)
@@ -79,6 +82,8 @@ struct sipe_media_call_private {
 struct sipe_media_stream_private {
 	struct sipe_media_stream public;
 
+	gchar *timeout_key;
+
 	guchar *encryption_key;
 	int encryption_key_id;
 	gboolean remote_candidates_and_codecs_set;
@@ -101,12 +106,22 @@ struct sipe_media_stream_private {
 #define SIPE_MEDIA_STREAM         ((struct sipe_media_stream *) stream_private)
 #define SIPE_MEDIA_STREAM_PRIVATE ((struct sipe_media_stream_private *) stream)
 
+#define SIPE_MEDIA_STREAM_CONNECTION_TIMEOUT_SECONDS 30
+#define SIPE_MEDIA_CALL_RINGING_TIMEOUT_SECONDS 60
+#define SIPE_MEDIA_CALL_TIMEOUT_SECONDS 120
+
 struct async_read_data {
 	guint8 *buffer;
 	gssize len;
 	sipe_media_stream_read_callback callback;
 };
 
+static void stream_schedule_cancel_timeout(struct sipe_media_call *call,
+					   struct sipe_media_stream_private *stream_private);
+
+static void call_schedule_cancel_request_timeout(struct sipe_media_call *call);
+static void call_schedule_cancel_ringing_timeout(struct sipe_media_call *call);
+
 static void sipe_media_codec_list_free(GList *codecs)
 {
 	for (; codecs; codecs = g_list_delete_link(codecs, codecs))
@@ -126,6 +141,8 @@ sipe_media_stream_free(struct sipe_media_stream_private *stream_private)
 
 	call_private = (struct sipe_media_call_private *)SIPE_MEDIA_STREAM->call;
 
+	stream_schedule_cancel_timeout(SIPE_MEDIA_CALL, stream_private);
+
 	sipe_media_stream_set_data(SIPE_MEDIA_STREAM, NULL, NULL);
 
 	if (call_private) {
@@ -136,6 +153,7 @@ sipe_media_stream_free(struct sipe_media_stream_private *stream_private)
 			call_private->ssrc_ranges =
 				g_slist_remove(call_private->ssrc_ranges,
 					       SIPE_MEDIA_STREAM->ssrc_range);
+			g_free(SIPE_MEDIA_STREAM->ssrc_range);
 		}
 	}
 
@@ -166,6 +184,9 @@ sipe_media_call_free(struct sipe_media_call_private *call_private)
 		g_hash_table_foreach_remove(call_private->sipe_private->media_calls,
 					    (GHRFunc) call_private_equals, call_private);
 
+		call_schedule_cancel_request_timeout(SIPE_MEDIA_CALL);
+		call_schedule_cancel_ringing_timeout(SIPE_MEDIA_CALL);
+
 		while (call_private->streams) {
 			sipe_media_stream_free(call_private->streams->data);
 		}
@@ -673,7 +694,7 @@ sipe_invite_call(struct sipe_media_call_private *call_private, TransCallback tc)
 }
 
 static void
-send_response_with_session_description(struct sipe_media_call_private *call_private, int code, gchar *text)
+send_response_with_session_description(struct sipe_media_call_private *call_private, int code, const gchar *text)
 {
 	struct sdpmsg *msg = sipe_media_to_sdpmsg(call_private);
 	gchar *body = sdpmsg_to_string(msg);
@@ -758,6 +779,12 @@ update_call_from_remote_sdp(struct sipe_media_call_private* call_private,
 				SIPE_MEDIA_STREAM_PRIVATE->encryption_key,
 				media->encryption_key);
 		SIPE_MEDIA_STREAM_PRIVATE->encryption_key_id = media->encryption_key_id;
+	} else {
+		// We now know that the stream won't be encrypted.
+		// Allow unencrypted data to pass srtpdec freely
+		sipe_backend_media_set_require_encryption(SIPE_MEDIA_CALL,
+							  stream,
+							  FALSE);
 	}
 
 	result = sipe_backend_set_remote_codecs(SIPE_MEDIA_CALL, stream,
@@ -840,6 +867,127 @@ call_initialized(struct sipe_media_call *call)
 	return TRUE;
 }
 
+static void
+stream_connection_timeout_cb(struct sipe_core_private *sipe_private,
+			    gpointer data)
+{
+	struct sipe_media_call_private *call_private = data;
+
+	sipe_backend_notify_error(SIPE_CORE_PUBLIC,
+				  _("Couldn't create stream"),
+				  _("Connection timed out"));
+	sipe_backend_media_hangup(SIPE_MEDIA_CALL->backend_private, TRUE);
+}
+
+static void
+stream_schedule_timeout(struct sipe_media_call *call)
+{
+	GSList *i;
+	for (i = SIPE_MEDIA_CALL_PRIVATE->streams; i; i = i->next) {
+		struct sipe_media_stream_private *stream_private = i->data;
+
+                if (stream_private->established)
+				continue;
+		stream_private->timeout_key =
+			g_strdup_printf("<media-stream-connect><%s><%s>",
+					sipe_media_get_sip_dialog(call)->callid,
+					SIPE_MEDIA_STREAM->id);
+
+		sipe_schedule_seconds(SIPE_MEDIA_CALL_PRIVATE->sipe_private,
+				      stream_private->timeout_key,
+				      SIPE_MEDIA_CALL_PRIVATE,
+				      SIPE_MEDIA_STREAM_CONNECTION_TIMEOUT_SECONDS,
+				      stream_connection_timeout_cb,
+				      NULL);
+	}
+}
+
+static void
+stream_schedule_cancel_timeout(struct sipe_media_call *call,
+			       struct sipe_media_stream_private *stream_private)
+{
+	if (stream_private->timeout_key) {
+		sipe_schedule_cancel(SIPE_MEDIA_CALL_PRIVATE->sipe_private,
+				     stream_private->timeout_key);
+		g_free(stream_private->timeout_key);
+	}
+	stream_private->timeout_key = NULL;
+}
+
+static void
+call_request_timeout_cb(struct sipe_core_private *sipe_private,
+			    gpointer data)
+{
+	struct sipe_media_call_private *call_private = data;
+
+	sipe_backend_notify_error(SIPE_CORE_PUBLIC,
+				  _("Request timed out"),
+				  _("Call could not be answered"));
+	sipe_backend_media_hangup(SIPE_MEDIA_CALL->backend_private, TRUE);
+}
+
+static void
+call_schedule_request_timeout(struct sipe_media_call *call)
+{
+	SIPE_MEDIA_CALL_PRIVATE->timeout_key =
+		g_strdup_printf("<media-call-request><%s>", sipe_media_get_sip_dialog(call)->callid);
+
+	sipe_schedule_seconds(SIPE_MEDIA_CALL_PRIVATE->sipe_private,
+			      SIPE_MEDIA_CALL_PRIVATE->timeout_key,
+			      SIPE_MEDIA_CALL_PRIVATE,
+			      SIPE_MEDIA_CALL_TIMEOUT_SECONDS,
+			      call_request_timeout_cb,
+			      NULL);
+}
+
+static void
+call_schedule_cancel_request_timeout(struct sipe_media_call *call)
+{
+	if (SIPE_MEDIA_CALL_PRIVATE->timeout_key) {
+		sipe_schedule_cancel(SIPE_MEDIA_CALL_PRIVATE->sipe_private,
+				     SIPE_MEDIA_CALL_PRIVATE->timeout_key);
+		g_free(SIPE_MEDIA_CALL_PRIVATE->timeout_key);
+	}
+	SIPE_MEDIA_CALL_PRIVATE->timeout_key = NULL;
+}
+
+
+static void
+call_ringing_timeout_cb(struct sipe_core_private *sipe_private,
+			    gpointer data)
+{
+	struct sipe_media_call_private *call_private = data;
+
+	sip_transport_response(sipe_private, call_private->invitation,
+				       408, "Request Timeout", NULL);
+	sipe_backend_media_hangup(SIPE_MEDIA_CALL->backend_private, FALSE);
+}
+
+static void
+call_schedule_ringing_timeout(struct sipe_media_call *call)
+{
+	SIPE_MEDIA_CALL_PRIVATE->ringing_key =
+		g_strdup_printf("<media-call-ringing><%s>", sipe_media_get_sip_dialog(call)->callid);
+
+	sipe_schedule_seconds(SIPE_MEDIA_CALL_PRIVATE->sipe_private,
+			      SIPE_MEDIA_CALL_PRIVATE->ringing_key,
+			      SIPE_MEDIA_CALL_PRIVATE,
+			      SIPE_MEDIA_CALL_RINGING_TIMEOUT_SECONDS,
+			      call_ringing_timeout_cb,
+			      NULL);
+}
+
+static void
+call_schedule_cancel_ringing_timeout(struct sipe_media_call *call)
+{
+	if (SIPE_MEDIA_CALL_PRIVATE->ringing_key) {
+		sipe_schedule_cancel(SIPE_MEDIA_CALL_PRIVATE->sipe_private,
+				     SIPE_MEDIA_CALL_PRIVATE->ringing_key);
+		g_free(SIPE_MEDIA_CALL_PRIVATE->ringing_key);
+	}
+	SIPE_MEDIA_CALL_PRIVATE->ringing_key = NULL;
+}
+
 // Sends an invite response when the call is accepted and local candidates were
 // prepared, otherwise does nothing. If error response is sent, call_private is
 // disposed before function returns.
@@ -869,6 +1017,8 @@ maybe_send_first_invite_response(struct sipe_media_call_private *call_private)
 					  _("Encryption settings of peer are incompatible with ours."));
 	} else {
 		send_response_with_session_description(call_private, 200, "OK");
+		stream_schedule_timeout(SIPE_MEDIA_CALL);
+		call_schedule_cancel_ringing_timeout(SIPE_MEDIA_CALL);
 		sipmsg_free(call_private->invitation);
 		call_private->invitation = NULL;
 	}
@@ -1029,18 +1179,8 @@ sipe_media_call_new(struct sipe_core_private *sipe_private, const gchar* with,
 	dialog->with = g_strdup(with);
 
 	if (msg) {
-		gchar *newTag = gentag();
-		const gchar *oldHeader;
-		gchar *newHeader;
-
-		oldHeader = sipmsg_find_header(msg, "To");
-		newHeader = g_strdup_printf("%s;tag=%s", oldHeader, newTag);
-		sipmsg_remove_header_now(msg, "To");
-		sipmsg_add_header_now(msg, "To", newHeader);
-		g_free(newTag);
-		g_free(newHeader);
-
-		dialog->callid = g_strdup(sipmsg_find_header(msg, "Call-ID"));
+		sipmsg_update_to_header_tag(msg);
+		dialog->callid = g_strdup(sipmsg_find_call_id_header(msg));
 		sipe_dialog_parse(dialog, msg, FALSE);
 	} else {
 		dialog->callid = gencallid();
@@ -1088,6 +1228,22 @@ sipe_media_call_new(struct sipe_core_private *sipe_private, const gchar* with,
 	return SIPE_MEDIA_CALL;
 }
 
+static gboolean
+find_call_cb(SIPE_UNUSED_PARAMETER const gchar *callid,
+	     struct sipe_media_call *call,
+	     const gchar *with)
+{
+	return sipe_strequal(call->with, with);
+}
+
+struct sipe_media_call *
+sipe_media_call_find(struct sipe_core_private *sipe_private, const gchar *with)
+{
+	return g_hash_table_find(sipe_private->media_calls,
+				 (GHRFunc)find_call_cb,
+				 (gpointer)with);
+}
+
 void sipe_media_hangup(struct sipe_media_call_private *call_private)
 {
 	if (call_private) {
@@ -1265,6 +1421,13 @@ sipe_media_stream_add(struct sipe_media_call *call, const gchar *id,
 			stream_private->encryption_key[i] = rand() & 0xff;
 		}
 		stream_private->encryption_key_id = 1;
+		// We don't know yet whether the stream will be
+		// encrypted or not. Enable the require-encryption
+		// property at stream creation time anyway, we may
+		// disable it later if we don't receive encryption keys.
+		sipe_backend_media_set_require_encryption(call,
+							  SIPE_MEDIA_STREAM,
+							  TRUE);
 	}
 #endif
 
@@ -1344,6 +1507,7 @@ sipe_media_initiate_call(struct sipe_core_private *sipe_private,
 
 	append_2007_fallback_if_needed(call_private);
 
+	call_schedule_request_timeout(SIPE_MEDIA_CALL);
 	// Processing continues in stream_initialized_cb
 }
 
@@ -1507,7 +1671,7 @@ sipe_media_from_sipmsg(struct sipe_core_private *sipe_private,
 		       struct sipmsg *msg)
 {
 	return g_hash_table_lookup(sipe_private->media_calls,
-				   sipmsg_find_header(msg, "Call-ID"));
+				   sipmsg_find_call_id_header(msg));
 }
 
 static void
@@ -1608,7 +1772,7 @@ process_incoming_invite_call_parsed_sdp(struct sipe_core_private *sipe_private,
 	}
 
 	if (!call_private) {
-		gchar *with = parse_from(sipmsg_find_header(msg, "From"));
+		gchar *with = sipmsg_parse_from_address(msg);
 		SipeMediaCallFlags flags = 0;
 
 		if (strstr(msg->body, "m=data") ||
@@ -1667,6 +1831,7 @@ process_incoming_invite_call_parsed_sdp(struct sipe_core_private *sipe_private,
 		call_private->smsg = smsg;
 		sip_transport_response(sipe_private, call_private->invitation,
 				       180, "Ringing", NULL);
+		call_schedule_ringing_timeout(SIPE_MEDIA_CALL);
 		// Processing continues in stream_initialized_cb
 	} else {
 		apply_remote_message(call_private, smsg);
@@ -1775,6 +1940,8 @@ sipe_core_media_stream_candidate_pair_established(struct sipe_media_stream *stre
 	}
 	SIPE_MEDIA_STREAM_PRIVATE->established = TRUE;
 
+	stream_schedule_cancel_timeout(call, SIPE_MEDIA_STREAM_PRIVATE);
+
 	if (stream->candidate_pairs_established_cb) {
 		stream->candidate_pairs_established_cb(stream);
 	}
@@ -1970,6 +2137,8 @@ process_invite_call_response(struct sipe_core_private *sipe_private,
 	apply_remote_message(call_private, smsg);
 	sdpmsg_free(smsg);
 
+	stream_schedule_timeout(SIPE_MEDIA_CALL);
+	call_schedule_cancel_request_timeout(SIPE_MEDIA_CALL);
 	sipe_media_send_ack(sipe_private, msg, trans);
 
 	return TRUE;
