@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2011-2016 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2011-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -286,7 +286,7 @@ static void send_presence_soap(struct sipe_core_private *sipe_private,
 	gchar *tmp;
 	gchar *tmp2 = NULL;
 	gchar *res_note = NULL;
-	gchar *res_oof = NULL;
+	const gchar *res_oof = NULL;
 	const gchar *note_pub = NULL;
 	gchar *states = NULL;
 	gchar *calendar_data = NULL;
@@ -470,7 +470,8 @@ void sipe_ocs2005_apply_calendar_status(struct sipe_core_private *sipe_private,
 	/* then set status_id actually */
 	SIPE_DEBUG_INFO("sipe_apply_calendar_status: to %s for %s", status_id, sbuddy->name ? sbuddy->name : "" );
 	sipe_backend_buddy_set_status(SIPE_CORE_PUBLIC, sbuddy->name,
-				      sipe_status_token_to_activity(status_id));
+				      sipe_status_token_to_activity(status_id),
+		                      0);
 
 	/* set our account state to the one in roaming (including calendar info) */
 	self_uri = sip_uri_self(sipe_private);
