@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2016 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -153,16 +157,16 @@ static gboolean process_subscribe_response(struct sipe_core_private *sipe_privat
 					   struct sipmsg *msg,
 					   struct transaction *trans)
 {
-	const gchar *event = sipmsg_find_header(msg, "Event");
+	const gchar *event = sipmsg_find_event_header(msg);
 
 	/* No Event header - error or 2005 Public IM Connectivity (PIC) */
 	if (!event) {
 		struct sipmsg *request_msg = trans->msg;
-		event = sipmsg_find_header(request_msg, "Event");
+		event = sipmsg_find_event_header(request_msg);
 	}
 
 	if (event) {
-		gchar *with = parse_from(sipmsg_find_header(msg, "To"));
+		gchar *with = sipmsg_parse_to_address(msg);
 		const gchar *subscription_state = sipmsg_find_header(msg, "subscription-state");
 		gboolean terminated = subscription_state && strstr(subscription_state, "terminated");
 		gchar *key = sipe_subscription_key(event, with);
@@ -224,7 +228,7 @@ static gboolean process_subscribe_response(struct sipe_core_private *sipe_privat
 						    subscription);
 				key = NULL; /* table takes ownership of key */
 
-				subscription->dialog.callid = g_strdup(sipmsg_find_header(msg, "Call-ID"));
+				subscription->dialog.callid = g_strdup(sipmsg_find_call_id_header(msg));
 				subscription->dialog.cseq   = sipmsg_parse_cseq(msg);
 				subscription->dialog.with   = g_strdup(with);
 				subscription->event         = g_strdup(event);
@@ -459,7 +463,7 @@ static void sipe_process_presence_timeout(struct sipe_core_private *sipe_private
 					  const gchar *who,
 					  int timeout)
 {
-	const char *ctype = sipmsg_find_header(msg, "Content-Type");
+	const char *ctype = sipmsg_find_content_type_header(msg);
 	gchar *action_name = sipe_utils_presence_key(who);
 
 	SIPE_DEBUG_INFO("sipe_process_presence_timeout: Content-Type: %s", ctype ? ctype : "");
@@ -749,7 +753,7 @@ static void sipe_subscribe_resource_uri_with_context(const gchar *name,
 						     gchar **resources_uri)
 {
 	struct sipe_buddy *sbuddy = (struct sipe_buddy *)value;
-	gchar *context = sbuddy && sbuddy->just_added ? "><context/></resource>" : "/>";
+	const gchar *context = sbuddy && sbuddy->just_added ? "><context/></resource>" : "/>";
 	gchar *tmp = *resources_uri;
 
 	/* should be enough to include context one time */
@@ -899,7 +903,7 @@ static void sipe_subscription_expiration(struct sipe_core_private *sipe_private,
 					 struct sipmsg *msg,
 					 const gchar *event)
 {
-	const gchar *expires_header = sipmsg_find_header(msg, "Expires");
+	const gchar *expires_header = sipmsg_find_expires_header(msg);
 	guint timeout = expires_header ? strtol(expires_header, NULL, 10) : 0;
 
 	if (timeout) {
@@ -907,7 +911,7 @@ static void sipe_subscription_expiration(struct sipe_core_private *sipe_private,
 		if (timeout > 240) timeout -= 120;
 
 		if (sipe_strcase_equal(event, "presence")) {
-			gchar *who = parse_from(sipmsg_find_header(msg, "To"));
+			gchar *who = sipmsg_parse_to_address(msg);
 
 			if (SIPE_CORE_PRIVATE_FLAG_IS(BATCHED_SUPPORT)) {
 				sipe_process_presence_timeout(sipe_private, msg, who, timeout);
