@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-12 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2018 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -378,7 +378,8 @@ void sipe_backend_buddy_set_string(struct sipe_core_public *sipe_public,
 }
 
 void sipe_backend_buddy_refresh_properties(SIPE_UNUSED_PARAMETER struct sipe_core_public *sipe_public,
-					   SIPE_UNUSED_PARAMETER const gchar *uri)
+					   SIPE_UNUSED_PARAMETER const gchar *uri,
+	                                   SIPE_UNUSED_PARAMETER last_active)
 {
 	/* nothing to do here: already taken care of by Miranda */
 }
