@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2018 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,12 +36,19 @@
 
 #include "mediamanager.h"
 #include "agent.h"
+#include "version.h"
 
 #ifdef _WIN32
 /* wrappers for write() & friends for socket handling */
 #include "win32/win32dep.h"
 #endif
 
+#if PURPLE_VERSION_CHECK(3,0,0)
+/* nothing here yet */
+#else
+#define purple_config_dir purple_user_dir
+#endif
+
 #include "sipe-backend.h"
 #include "sipe-core.h"
 
@@ -125,8 +132,8 @@ maybe_signal_stream_initialized(struct sipe_media_call *call, gchar *sessionid)
 		if (stream &&
 		    sipe_backend_stream_initialized(call, stream) &&
 		    !stream->backend_private->initialized_cb_was_fired) {
-			call->stream_initialized_cb(call, stream);
 			stream->backend_private->initialized_cb_was_fired = TRUE;
+			call->stream_initialized_cb(call, stream);
 		}
 	}
 }
@@ -408,7 +415,7 @@ ensure_codecs_conf()
 	const gchar *fs_codecs_conf = FS_CODECS_CONF;
 	GError *error = NULL;
 
-	filename = g_build_filename(purple_user_dir(), "fs-codec.conf", NULL);
+	filename = g_build_filename(purple_config_dir(), "fs-codec.conf", NULL);
 
 	g_file_set_contents(filename, fs_codecs_conf, strlen(fs_codecs_conf),
 			    &error);
@@ -423,7 +430,7 @@ ensure_codecs_conf()
 
 static void
 append_relay(struct sipe_backend_media_relays *relay_info, const gchar *ip,
-	     guint port, gchar *type, gchar *username, gchar *password)
+	     guint port, const gchar *type, gchar *username, gchar *password)
 {
 	GstStructure *gst_relay_info;
 
@@ -461,7 +468,7 @@ sipe_backend_media_relays_convert(GSList *media_relays, gchar *username, gchar *
 
 #ifdef HAVE_PURPLE_NEW_TCP_ENUMS
 		if (relay->tcp_port != 0) {
-			gchar *type = "tcp";
+			const gchar *type = "tcp";
 			if (relay->tcp_port == 443)
 				type = "tls";
 			append_relay(relay_info, relay->hostname, relay->tcp_port,
@@ -809,6 +816,7 @@ gst_bus_cb(GstBus *bus, GstMessage *msg, struct sipe_media_stream *stream)
 		g_signal_handler_disconnect(bus,
 				stream->backend_private->gst_bus_cb_id);
 		stream->backend_private->gst_bus_cb_id = 0;
+		g_value_unset (&val);
 	}
 
 	gst_iterator_free(it);
@@ -827,10 +835,9 @@ sipe_backend_media_add_stream(struct sipe_media_stream *stream,
 	struct sipe_backend_media_stream *backend_stream = NULL;
 	GstElement *pipe;
 	// Preallocate enough space for all potential parameters to fit.
-	GParameter *params = g_new0(GParameter, 6);
+	GParameter *params = g_new0(GParameter, 7);
 	guint params_cnt = 0;
-	gchar *transmitter;
-	GValue *relay_info = NULL;
+	const gchar *transmitter;
 #ifdef HAVE_XDATA
 	PurpleMediaAppDataCallbacks callbacks = {
 			stream_readable_cb, stream_writable_cb
@@ -866,7 +873,6 @@ sipe_backend_media_add_stream(struct sipe_media_stream *stream,
 			params[params_cnt].name = "relay-info";
 			g_value_init(&params[params_cnt].value, G_TYPE_PTR_ARRAY);
 			g_value_set_boxed(&params[params_cnt].value, media_relays);
-			relay_info = &params[params_cnt].value;
 			++params_cnt;
 		}
 
@@ -881,6 +887,23 @@ sipe_backend_media_add_stream(struct sipe_media_stream *stream,
 			g_value_set_boolean(&params[params_cnt].value, TRUE);
 			++params_cnt;
 		}
+
+		/* Don't use the globally defined stun server (it is used by
+		 * default in backend-fs2) because it generates srflx local
+		 * candidates that confuse SfB when they contribute to valid
+		 * pairs in controlled mode:
+		 *
+		 * ms-client-diagnostics: 21
+		 *   "Call failed to establish due to a media connectivity
+		 *   failure where one endpoint is of unknown type"
+		 *
+		 * These candidates will be discovered anyway during the
+		 * conncheck as prflx, and they will be accepted and nominated
+		 * by SfB when having this type. */
+		params[params_cnt].name = "stun-ip";
+		g_value_init(&params[params_cnt].value, G_TYPE_STRING);
+		g_value_set_string(&params[params_cnt].value, NULL);
+		++params_cnt;
 	} else {
 		// TODO: session naming here, Communicator needs audio/video
 		transmitter = "rawudp";
@@ -921,10 +944,6 @@ sipe_backend_media_add_stream(struct sipe_media_stream *stream,
 		backend_stream = NULL;
 	}
 
-	if (relay_info) {
-		g_value_unset(relay_info);
-	}
-
 	g_free(params);
 
 	return backend_stream;
@@ -1082,6 +1101,23 @@ sipe_backend_media_set_encryption_keys(SIPE_UNUSED_PARAMETER struct sipe_media_c
 {}
 #endif
 
+#if defined(HAVE_SRTP) && PURPLE_VERSION_CHECK(2,14,0)
+void
+sipe_backend_media_set_require_encryption(struct sipe_media_call *media,
+					  struct sipe_media_stream *stream,
+					  const gboolean require_encryption)
+{
+	purple_media_set_require_encryption(media->backend_private->m,
+			stream->id, media->with, require_encryption);
+}
+#else
+void
+sipe_backend_media_set_require_encryption(SIPE_UNUSED_PARAMETER struct sipe_media_call *media,
+					  SIPE_UNUSED_PARAMETER struct sipe_media_stream *stream,
+					  SIPE_UNUSED_PARAMETER const gboolean require_encryption)
+{}
+#endif
+
 void sipe_backend_stream_hold(struct sipe_media_call *media,
 			      struct sipe_media_stream *stream,
 			      gboolean local)
