@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2010-2017 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2010-2019 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,15 +36,8 @@
 #include "request.h"
 #include "version.h"
 
-#ifdef HAVE_DBUS
-#include "purple-dbus.h"
-#endif
-
-#if !(PURPLE_VERSION_CHECK(2,7,0) || PURPLE_VERSION_CHECK(3,0,0))
-#error purple >= 2.7.0 is required to build SIPE
-#endif
-
 #if PURPLE_VERSION_CHECK(3,0,0)
+#include "action.h"
 #define PURPLE_TYPE_STRING G_TYPE_STRING
 #define SIPE_PURPLE_ACTION_TO_CONNECTION              action->connection
 #else
@@ -111,7 +104,8 @@ static const gchar * const activity_to_purple_map[SIPE_ACTIVITY_NUM_TYPES] = {
 /* SIPE_ACTIVITY_IN_MEETING  */ "in-a-meeting",
 /* SIPE_ACTIVITY_OOF         */ "out-of-office",
 /* SIPE_ACTIVITY_URGENT_ONLY */ "urgent-interruptions-only",
-/* SIPE_ACTIVIY_NUM_TYPES == 17 -> compare to sipe_purple_status_types() */
+/* SIPE_ACTIVITY_IN_PRES     */ "presenting",
+/* SIPE_ACTIVIY_NUM_TYPES == 18 -> compare to sipe_purple_status_types() */
 };
 
 GHashTable *purple_token_map;
@@ -158,7 +152,7 @@ const char *sipe_purple_list_icon(SIPE_UNUSED_PARAMETER PurpleAccount *a,
 
 gchar *sipe_purple_status_text(PurpleBuddy *buddy)
 {
-	const PurpleStatus *status = purple_presence_get_active_status(purple_buddy_get_presence(buddy));
+	PurpleStatus *status = purple_presence_get_active_status(purple_buddy_get_presence(buddy));
 	return sipe_core_buddy_status(PURPLE_BUDDY_TO_SIPE_CORE_PUBLIC,
 				      purple_buddy_get_name(buddy),
 				      sipe_purple_token_to_activity(purple_status_get_id(status)),
@@ -169,7 +163,7 @@ void sipe_purple_tooltip_text(PurpleBuddy *buddy,
 			      PurpleNotifyUserInfo *user_info,
 			      SIPE_UNUSED_PARAMETER gboolean full)
 {
-	const PurplePresence *presence = purple_buddy_get_presence(buddy);
+	PurplePresence *presence = purple_buddy_get_presence(buddy);
 	sipe_core_buddy_tooltip_info(PURPLE_BUDDY_TO_SIPE_CORE_PUBLIC,
 				     purple_buddy_get_name(buddy),
 				     purple_status_get_name(purple_presence_get_active_status(presence)),
@@ -260,6 +254,11 @@ GList *sipe_purple_status_types(SIPE_UNUSED_PARAMETER PurpleAccount *acc)
 			SIPE_ACTIVITY_URGENT_ONLY,
 			FALSE);
 
+	/* Presenting */
+	SIPE_ADD_STATUS(PURPLE_STATUS_UNAVAILABLE,
+			SIPE_ACTIVITY_IN_PRES,
+			FALSE);
+
 	/*
 	 * Status list entries for primitive type AWAY
 	 *
@@ -620,7 +619,7 @@ sipe_purple_get_account_text_table(SIPE_UNUSED_PARAMETER PurpleAccount *account)
 {
 	GHashTable *table;
 	table = g_hash_table_new(g_str_hash, g_str_equal);
-	g_hash_table_insert(table, "login_label", (gpointer)_("user@company.com"));
+	g_hash_table_insert(table, (char *)"login_label", (gpointer)_("user@company.com"));
 	return table;
 }
 
@@ -653,13 +652,6 @@ PurpleMediaCaps sipe_purple_get_media_caps(SIPE_UNUSED_PARAMETER PurpleAccount *
 /* PurplePluginInfo function calls & data structure */
 gboolean sipe_purple_plugin_load(SIPE_UNUSED_PARAMETER PurplePlugin *plugin)
 {
-#ifdef HAVE_DBUS
-	if (purple_dbus_get_init_error() == NULL) {
-		SIPE_DEBUG_INFO_NOFORMAT("sipe_purple_plugin_load: registering D-Bus bindings");
-		purple_dbus_register_bindings(plugin, sipe_purple_dbus_bindings);
-	}
-#endif
-
 #ifdef HAVE_VV
 	{
 		struct sigaction action;
@@ -979,7 +971,14 @@ GList * sipe_purple_account_options()
 gpointer sipe_purple_user_split()
 {
 	PurpleAccountUserSplit *split =
-			purple_account_user_split_new(_("Login\n   user  or  DOMAIN\\user  or\n   user@company.com"), NULL, ',');
+		purple_account_user_split_new(
+			_("Login\n   user  or  DOMAIN\\user  or\n   user@company.com"),
+			/*
+			 * pidgin works fine with NULL as default
+			 * finch returns string "(null)" for NULL
+			 */
+			"",
+			',');
 	purple_account_user_split_set_reverse(split, FALSE);
 
 	return split;
